<?php

namespace Drupal\tcmb\Plugin\Block;

use Drupal\Core\Block\BlockBase;

/**
 * Provides a 'Tcmb Currency' block.
 *
 * @Block (
 *  id = "tcmb_block",
 *  admin_label = @Translation("Tcmb: currency"),
 *  category = @Translation("Tcmb")
 * )
 */
class TcmbCurrencyBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $conn = \Drupal::database();
    $config = \Drupal::config('tcmb.settings');
    $records = $conn->select('tcmb', 't')
      ->fields('t', [
        'updated',
      ])
      ->range(0, 1)
      ->orderBy('updated', 'DESC')
      ->execute()
      ->fetchAssoc();
    $updated = date('Y-m-d', strtotime($records['updated']));
    $tcmb_currency_codes = $config->get('tcmb_currency_codes', []);
    $records = $conn->select('tcmb', 't')
      ->fields('t', [
        'currency_name',
        'currency_code',
        'updated',
        'buying',
        'selling',
      ])
      ->condition('currency_code', $tcmb_currency_codes, 'IN')
      ->condition('updated', $updated)
      ->groupBy('currency_code')
      ->groupBy('currency_name')
      ->groupBy('updated')
      ->groupBy('buying')
      ->groupBy('selling');
    $results = $records->execute()->fetchAll(\PDO::FETCH_ASSOC);
    $header = [t('Currency'), t('Buying'), t('Selling')];
    $rows = [];
    $build = [
      '#type' => 'table',
      '#header' => $header,
    ];
    foreach ($results as $result) {
      $title = $result['currency_name'];
      $image = \Drupal::service('extension.list.module')->getPath('tcmb') . '/png/' . strtolower($result['currency_code']) . '.png';
      $id = $result['currency_name'];
      $build[$id]['image'] = [
        '#theme' => 'image',
        '#uri' => $image,
        '#alt' => $title,
        '#title' => $title,
        '#suffix' => " " . $result['currency_code'],
      ];
      $build[$id]['buy'] = [
        '#markup' => $result['buying'],
      ];
      $build[$id]['sell'] = [
        '#markup' => $result['selling'],
      ];
    }
    return [
      '#markup' => \Drupal::service('renderer')->render($build),
      '#suffix' => ($config->get('tcmb_show_currency_block_footer')) ? t('Exchange rates are updated once a day on 15:30 on weekdays.') : '',
      '#cache' => [
        'max-age' => 50000,
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $conn = \Drupal::database();
    $config = \Drupal::config('tcmb.settings');
    $records = $conn->select('tcmb', 't')
      ->fields('t', [
        'updated',
      ])
      ->range(0, 1)
      ->orderBy('updated', 'DESC')
      ->execute()
      ->fetchAssoc();
    $updated = date('Y-m-d', strtotime($records['updated']));
    $tcmb_currency_codes = $config->get('tcmb_currency_codes', []);
    $records = $conn->select('tcmb', 't')
      ->fields('t', [
        'currency_name',
        'currency_code',
        'updated',
        'buying',
        'selling',
      ])
      ->condition('currency_code', $tcmb_currency_codes, 'IN')
      ->condition('updated', $updated)
      ->groupBy('currency_code')
      ->groupBy('currency_name')
      ->groupBy('updated')
      ->groupBy('buying')
      ->groupBy('selling');
    $results = $records->execute()->fetchAll(\PDO::FETCH_ASSOC);
    return [
      'label' => ($config->get('tcmb_show_currency_block_title')) ? t('TCMB rates for :updated', [':updated' => date('d-m-Y', strtotime($results[0]['updated']))]) : '',
    ];
  }

}
